@@ -19,6 +19,8 @@
 #ifndef _ALPM_LIST_H
 #define _ALPM_LIST_H
 
+#include <stdlib.h> /* size_t */
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -45,7 +47,6 @@ typedef void (*alpm_list_fn_free)(void *); /* item deallocation callback */
 typedef int (*alpm_list_fn_cmp)(const void *, const void *); /* item comparison callback */
 
 /* allocation */
-alpm_list_t *alpm_list_new(void);
 void alpm_list_free(alpm_list_t *list);
 void alpm_list_free_inner(alpm_list_t *list, alpm_list_fn_free fn);
 
@@ -56,6 +57,7 @@ alpm_list_t *alpm_list_join(alpm_list_t *first, alpm_list_t *second);
 alpm_list_t *alpm_list_mmerge(alpm_list_t *left, alpm_list_t *right, alpm_list_fn_cmp fn);
 alpm_list_t *alpm_list_msort(alpm_list_t *list, int n, alpm_list_fn_cmp fn);
 alpm_list_t *alpm_list_remove(alpm_list_t *haystack, const void *needle, alpm_list_fn_cmp fn, void **data);
+alpm_list_t *alpm_list_remove_str(alpm_list_t *haystack, const char *needle, char **data);
 alpm_list_t *alpm_list_remove_dupes(const alpm_list_t *list);
 alpm_list_t *alpm_list_strdup(const alpm_list_t *list);
 alpm_list_t *alpm_list_copy(const alpm_list_t *list);
