@@ -29,31 +29,30 @@
 /* Dependency */
 struct __pmdepend_t {
 	pmdepmod_t mod;
-	char name[PKG_NAME_LEN];
-	char version[PKG_VERSION_LEN];
+	char *name;
+	char *version;
 };
 
 /* Missing dependency */
 struct __pmdepmissing_t {
-	char target[PKG_NAME_LEN];
-	pmdepend_t depend;
+	char *target;
+	pmdepend_t *depend;
+	char *causingpkg; /* this is used in case of remove dependency error only */
 };
 
-/* Graphs */
-struct __pmgraph_t {
-	int state; /* 0: untouched, -1: entered, other: leaving time */
-	void *data;
-	struct __pmgraph_t *parent; /* where did we come from? */
-	alpm_list_t *children;
-	alpm_list_t *childptr; /* points to a child in children list */
-};
-
-pmdepmissing_t *_alpm_depmiss_new(const char *target, pmdepmod_t depmod,
-		const char *depname, const char *depversion);
-alpm_list_t *_alpm_sortbydeps(alpm_list_t *targets, pmtranstype_t mode);
+void _alpm_dep_free(pmdepend_t *dep);
+pmdepend_t *_alpm_dep_dup(const pmdepend_t *dep);
+pmdepmissing_t *_alpm_depmiss_new(const char *target, pmdepend_t *dep,
+		const char *causinpkg);
+void _alpm_depmiss_free(pmdepmissing_t *miss);
+alpm_list_t *_alpm_sortbydeps(alpm_list_t *targets, int reverse);
 void _alpm_recursedeps(pmdb_t *db, alpm_list_t *targs, int include_explicit);
-int _alpm_resolvedeps(pmdb_t *local, alpm_list_t *dbs_sync, pmpkg_t *syncpkg,
-                      alpm_list_t **list, alpm_list_t *remove, pmtrans_t *trans, alpm_list_t **data);
+pmpkg_t *_alpm_resolvedep(pmdepend_t *dep, alpm_list_t *dbs, alpm_list_t *excluding, pmpkg_t *tpkg);
+int _alpm_resolvedeps(pmdb_t *local, alpm_list_t *dbs_sync, alpm_list_t *list,
+		      alpm_list_t *remove, alpm_list_t **data);
+int _alpm_dep_edge(pmpkg_t *pkg1, pmpkg_t *pkg2);
+pmdepend_t *_alpm_splitdep(const char *depstring);
+pmpkg_t *_alpm_find_dep_satisfier(alpm_list_t *pkgs, pmdepend_t *dep);
 
 #endif /* _ALPM_DEPS_H */
 
