@@ -30,7 +30,6 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/statvfs.h>
-#include <unistd.h>
 #include <errno.h>
 
 /* libalpm */
@@ -205,7 +204,7 @@ int SYMEXPORT alpm_trans_release()
 
 	/* unlock db */
 	if(handle->lckfd != -1) {
-		close(handle->lckfd);
+		while(close(handle->lckfd) == -1 && errno == EINTR);
 		handle->lckfd = -1;
 	}
 	if(_alpm_lckrm()) {
@@ -561,8 +560,7 @@ int _alpm_runscriptlet(const char *root, const char *installfn,
 		if(!pipe) {
 			_alpm_log(PM_LOG_ERROR, _("call to popen failed (%s)"),
 					strerror(errno));
-			retval = 1;
-			goto cleanup;
+			exit(1);
 		}
 		while(!feof(pipe)) {
 			char line[PATH_MAX];
@@ -571,12 +569,13 @@ int _alpm_runscriptlet(const char *root, const char *installfn,
 			alpm_logaction("%s", line);
 			EVENT(trans, PM_TRANS_EVT_SCRIPTLET_INFO, line, NULL);
 		}
-		exit(0);
+		retval = pclose(pipe);
+		exit(WEXITSTATUS(retval));
 	} else {
 		/* this code runs for the parent only (wait on the child) */
 		pid_t retpid;
 		int status;
-		retpid = waitpid(pid, &status, 0);
+		while((retpid = waitpid(pid, &status, 0)) == -1 && errno == EINTR);
 		if(retpid == -1) {
 			_alpm_log(PM_LOG_ERROR, _("call to waitpid failed (%s)\n"),
 			          strerror(errno));
