@@ -27,7 +27,6 @@ typedef struct __config_t {
 	unsigned short verbose;
 	unsigned short version;
 	unsigned short help;
-	unsigned short upgrade;
 	unsigned short noconfirm;
 	unsigned short noprogressbar;
 	unsigned short logmask;
@@ -53,7 +52,6 @@ typedef struct __config_t {
 	unsigned short op_q_upgrade;
 
 	unsigned short op_s_clean;
-	unsigned short op_s_dependsonly;
 	unsigned short op_s_downloadonly;
 	unsigned short op_s_info;
 	unsigned short op_s_sync;
@@ -65,17 +63,17 @@ typedef struct __config_t {
 
 	/* conf file options */
 	unsigned short chomp; /* I Love Candy! */
-	unsigned short usecolor; /* enable colorful output */
 	unsigned short showsize; /* show individual package sizes */
-	unsigned short totaldownload; /* When downloading, display the amount
-	                                 downloaded, rate, ETA, and percent
-	                                 downloaded of the total download list */
+	/* When downloading, display the amount downloaded, rate, ETA, and percent
+	 * downloaded of the total download list */
+	unsigned short totaldownload;
+	unsigned short cleanmethod; /* select -Sc behavior */
+	alpm_list_t *syncfirst;
 } config_t;
 
 /* Operations */
 enum {
 	PM_OP_MAIN = 1,
-	PM_OP_ADD,
 	PM_OP_REMOVE,
 	PM_OP_UPGRADE,
 	PM_OP_QUERY,
@@ -83,6 +81,12 @@ enum {
 	PM_OP_DEPTEST
 };
 
+/* clean method */
+enum {
+	PM_CLEAN_KEEPINST = 0, /* default */
+	PM_CLEAN_KEEPCUR
+};
+
 /* global config variable */
 extern config_t *config;
 
