@@ -36,6 +36,7 @@
 #include <sys/utsname.h> /* uname */
 #include <locale.h> /* setlocale */
 #include <time.h> /* time_t */
+#include <errno.h>
 #if defined(PACMAN_DEBUG) && defined(HAVE_MCHECK_H)
 #include <mcheck.h> /* debug tracing (mtrace) */
 #endif
@@ -211,21 +212,34 @@ static void cleanup(int ret) {
 	exit(ret);
 }
 
+/** Write function that correctly handles EINTR.
+ */
+static ssize_t xwrite(int fd, const void *buf, size_t count)
+{
+	ssize_t ret;
+	while((ret = write(fd, buf, count)) == -1 && errno == EINTR);
+	return(ret);
+}
+
 /** Catches thrown signals. Performs necessary cleanup to ensure database is
  * in a consistant state.
  * @param signum the thrown signal
  */
 static RETSIGTYPE handler(int signum)
 {
-	if(signum==SIGSEGV)
-	{
-		/* write a log message and write to stderr */
-		pm_printf(PM_LOG_ERROR, _("segmentation fault\n"));
-		pm_fprintf(stderr, PM_LOG_ERROR,
-				_("Internal pacman error: Segmentation fault.\n"
-					"Please submit a full bug report with --debug if appropriate.\n"));
+	int out = fileno(stdout);
+	int err = fileno(stderr);
+	if(signum == SIGSEGV) {
+		const char *msg1 = "error: segmentation fault\n";
+		const char *msg2 = "Internal pacman error: Segmentation fault.\n"
+			"Please submit a full bug report with --debug if appropriate.\n";
+		/* write a error message to out, the rest to err */
+		xwrite(out, msg1, strlen(msg1));
+		xwrite(err, msg2, strlen(msg2));
 		exit(signum);
 	} else if((signum == SIGINT)) {
+		const char *msg = "\nInterrupt signal received\n";
+		xwrite(err, msg, strlen(msg));
 		if(alpm_trans_interrupt() == 0) {
 			/* a transaction is being interrupted, don't exit pacman yet. */
 			return;
@@ -233,7 +247,7 @@ static RETSIGTYPE handler(int signum)
 		/* no commiting transaction, we can release it now and then exit pacman */
 		alpm_trans_release();
 		/* output a newline to be sure we clear any line we may be on */
-		printf("\n");
+		xwrite(out, "\n", 1);
 	}
 	cleanup(signum);
 }
@@ -262,11 +276,13 @@ static void setlibpaths(void)
 				cleanup(ret);
 			}
 			if(!config->dbpath) {
-				snprintf(path, PATH_MAX, "%s%s", alpm_option_get_root(), DBPATH);
+				/* omit leading slash from our static DBPATH, root handles it */
+				snprintf(path, PATH_MAX, "%s%s", alpm_option_get_root(), DBPATH + 1);
 				config->dbpath = strdup(path);
 			}
 			if(!config->logfile) {
-				snprintf(path, PATH_MAX, "%s%s", alpm_option_get_root(), LOGFILE);
+				/* omit leading slash from our static LOGFILE path, root handles it */
+				snprintf(path, PATH_MAX, "%s%s", alpm_option_get_root(), LOGFILE + 1);
 				config->logfile = strdup(path);
 			}
 		}
@@ -561,6 +577,7 @@ static int _parseconfig(const char *file, const char *givensection,
 	int linenum = 0;
 	char *ptr, *section = NULL;
 	pmdb_t *db = NULL;
+	int ret = 0;
 
 	pm_printf(PM_LOG_DEBUG, "config: attempting to read file %s\n", file);
 	fp = fopen(file, "r");
@@ -603,7 +620,8 @@ static int _parseconfig(const char *file, const char *givensection,
 			if(!strlen(section)) {
 				pm_printf(PM_LOG_ERROR, _("config file %s, line %d: bad section name.\n"),
 						file, linenum);
-				return(1);
+				ret = 1;
+				goto cleanup;
 			}
 			/* if we are not looking at the options section, register a db and also
 			 * ensure we have set all of our library paths as the library is too stupid
@@ -611,6 +629,12 @@ static int _parseconfig(const char *file, const char *givensection,
 			if(strcmp(section, "options") != 0) {
 				setlibpaths();
 				db = alpm_db_register_sync(section);
+				if(db == NULL) {
+					pm_printf(PM_LOG_ERROR, _("could not register '%s' database (%s)\n"),
+							section, alpm_strerrorlast());
+					ret = 1;
+					goto cleanup;
+				}
 			}
 		} else {
 			/* directive */
@@ -625,13 +649,15 @@ static int _parseconfig(const char *file, const char *givensection,
 			if(key == NULL) {
 				pm_printf(PM_LOG_ERROR, _("config file %s, line %d: syntax error in config file- missing key.\n"),
 						file, linenum);
-				return(1);
+				ret = 1;
+				goto cleanup;
 			}
 			/* For each directive, compare to the camelcase string. */
 			if(section == NULL) {
 				pm_printf(PM_LOG_ERROR, _("config file %s, line %d: All directives must belong to a section.\n"),
 						file, linenum);
-				return(1);
+				ret = 1;
+				goto cleanup;
 			}
 			if(ptr == NULL && strcmp(section, "options") == 0) {
 				/* directives without settings, all in [options] */
@@ -656,7 +682,8 @@ static int _parseconfig(const char *file, const char *givensection,
 				} else {
 					pm_printf(PM_LOG_ERROR, _("config file %s, line %d: directive '%s' not recognized.\n"),
 							file, linenum, key);
-					return(1);
+					ret = 1;
+					goto cleanup;
 				}
 			} else {
 				/* directives with settings */
@@ -687,7 +714,8 @@ static int _parseconfig(const char *file, const char *givensection,
 						if(alpm_option_add_cachedir(ptr) != 0) {
 							pm_printf(PM_LOG_ERROR, _("problem adding cachedir '%s' (%s)\n"),
 									ptr, alpm_strerrorlast());
-							return(1);
+							ret = 1;
+							goto cleanup;
 						}
 						pm_printf(PM_LOG_DEBUG, "config: cachedir: %s\n", ptr);
 					} else if(strcmp(key, "RootDir") == 0) {
@@ -711,13 +739,15 @@ static int _parseconfig(const char *file, const char *givensection,
 							config->cleanmethod = PM_CLEAN_KEEPCUR;
 						} else {
 							pm_printf(PM_LOG_ERROR, _("invalid value for 'CleanMethod' : '%s'\n"), ptr);
-							return(1);
+							ret = 1;
+							goto cleanup;
 						}
 						pm_printf(PM_LOG_DEBUG, "config: cleanmethod: %s\n", ptr);
 					} else {
 						pm_printf(PM_LOG_ERROR, _("config file %s, line %d: directive '%s' not recognized.\n"),
 								file, linenum, key);
-						return(1);
+						ret = 1;
+						goto cleanup;
 					}
 				} else if(strcmp(key, "Server") == 0) {
 					/* let's attempt a replacement for the current repo */
@@ -725,27 +755,35 @@ static int _parseconfig(const char *file, const char *givensection,
 
 					if(alpm_db_setserver(db, server) != 0) {
 						/* pm_errno is set by alpm_db_setserver */
-						return(1);
+						pm_printf(PM_LOG_ERROR, _("could not add server URL to database '%s': %s (%s)\n"),
+								alpm_db_get_name(db), server, alpm_strerrorlast());
+						free(server);
+						ret = 1;
+						goto cleanup;
 					}
 
 					free(server);
 				} else {
 					pm_printf(PM_LOG_ERROR, _("config file %s, line %d: directive '%s' not recognized.\n"),
 							file, linenum, key);
-					return(1);
+					ret = 1;
+					goto cleanup;
 				}
 			}
 		}
 	}
-	fclose(fp);
+
+cleanup:
+	if(fp) {
+		fclose(fp);
+	}
 	if(section){
 		free(section);
 	}
-
 	/* call setlibpaths here to ensure we have called it at least once */
 	setlibpaths();
 	pm_printf(PM_LOG_DEBUG, "config: finished parsing %s\n", file);
-	return(0);
+	return(ret);
 }
 
 /** Parse a configuration file.
